How to contribute to Vumi Freeswitch ESL
========================================

Vumi Freeswitch ESL is an Open Source software project under the BSD license.
We love contributions!

Here's a quick guide on how to contribute to the project:

1.  Fork the repository
2.  Run the tests, we'll only accept pull requests with passing tests.
    Ensure that the tests run with ``trial vxfreeswitch`` and that you're starting
    with a clean slate.
3.  Make your changes to your forked repository and ensure that tests are
    added where necessary.
4.  Make the tests pass.
5.  Push to your fork and submit a pull request!
    (For bonus points use hub_ if you're turning an
    existing issue into a pull request)

At this point you're waiting on us. We like to comment on pull-requests
and where needed possibly request some changes, improvements or alternatives.

Please ensure that your code is PEP8_ compliant and you use 4 spaces
for indentation, tabs are right out.


.. _PEP8: http://www.python.org/dev/peps/pep-0008/
.. _hub: http://defunkt.io/hub/
